<?php
/**
 * The Horde_Editor_xinha:: class provides an WYSIWYG editor for use
 * in the Horde Framework.
 *
 * $Horde: framework/Editor/Editor/xinha.php,v 1.7 2006/02/22 14:46:24 jan Exp $
 *
 * Copyright 2003-2006 Nuno Loureiro <nuno@co.sapo.pt>
 * Copyright 2004-2006 Jan Schneider <jan@horde.org>
 *
 * See the enclosed file COPYING for license information (LGPL). If you
 * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
 *
 * @author  Nuno Loureiro <nuno@co.sapo.pt>
 * @author  Jan Schneider <jan@horde.org>
 * @author  Roel Gloudemans <roel@gloudemans.info>
 * @since   Horde 3.2
 * @package Horde_Editor
 */
class Horde_Editor_xinha extends Horde_Editor {

    /**
     * Constructor. Include the necessary javascript files.
     */
    function Horde_Editor_xinha($params = array())
    {
        global $registry, $notification, $prefs;

        $js  = 'var _editor_url = \'' . $registry->get('webroot', 'horde') . '/services/editor/xinha/\'; ' .
               'xinha_editors = null; ' .
               'xinha_init = null; ' .
               'xinha_config = null; ' .
               'xinha_plugins = null; ' .

               'xinha_init = xinha_init ? xinha_init : function() { ';

        // Loading plugins.
        $js .= 'var plugins = []; ';
        if ($prefs->getValue('anselimage') && $registry->hasMethod('images/listGalleries')) {
            $js .= 'plugins.push(\'AnselImage\'); ';
        }

        if ($prefs->getValue('listtype')) {
            $js .= 'plugins.push(\'ListType\'); ';
        }

        if ($prefs->getValue('contextmenu')) {
            $js .= 'plugins.push(\'ContextMenu\'); ';
        }

        if ($prefs->getValue('tableoperations')) {
            $js .= 'plugins.push(\'TableOperations\'); ';
        }

        if ($prefs->getValue('charactermap')) {
            $js .= 'plugins.push(\'CharacterMap\'); ';
        }

        $js .= 'xinha_plugins = xinha_plugins ? xinha_plugins : plugins; if (!HTMLArea.loadPlugins(xinha_plugins, xinha_init)) return; ';

        if (isset($params['id'])) {
            $js .= 'var xinha_editors = [document.getElementById(\'' . $params['id'] . '\')]; ';
        } else {
            $js .= 'var xinha_editors = document.getElementsByTagName(\'TEXTAREA\'); ';
        }

        $js .= 'xinha_config = xinha_config ? xinha_config() : new HTMLArea.Config(); xinha_config.debug = false; xinha_config.hideSomeButtons(\' showhelp \'); ';

        if (isset($params['relativelinks'])) {
            $myserver = Horde::url('', true);
            $myserver = substr($myserver, 0, strpos($myserver, '/', 8));

            $js .= 'xinha_config.stripBaseHref = true; xinha_config.stripSelftNamedAnchors = true; xinha_config.baseHref = \'' . $myserver . '\'; ';
        }

        if (isset($params['config'])) {
            foreach ($params['config'] as $config => $value) {
                $js .= 'xinha_config.' . $config . ' = \'' . addslashes($value) . '\'; ';
            }
        }

        $js .= 'xinha_editors = HTMLArea.makeEditors(xinha_editors, xinha_config, xinha_plugins); HTMLArea.startEditors(xinha_editors); }; addEvent(window, \'load\', xinha_init); ';

        $notification->push($js, 'javascript');
        $notification->push($registry->get('webroot', 'horde') . '/services/editor/xinha/htmlarea.js', 'javascript-file');
    }

}
